@@ -1,4 +1,4 @@
-from .corpus import GenerationDataset, NsmcCorpus
+from .corpus import *
 from .task import GenerationTask
 from .arguments import GenerationTrainArguments, GenerationDeployArguments
 from .deploy import get_web_service_app
